### Tools for Air Quality Data Analysis

Python Library to better understand the air quality data through visualizations.

Inspired from the R package [OpenAir][3].


Documentations
==============
View documentations hosted at [GitHub][1].

# Installation

```shell
pip install vayu
```

# Sample Usage
For sample usage please look for jupyer notebooks in `examples/nbs` in the [official repository][2].

[1]: https://sustainability-lab.github.io/vayu/
[2]: https://github.com/sustainability-lab/vayu/
[3]: https://davidcarslaw.github.io/openair/
